caellion-python-commons: caellion.pycommons.stringutil.unixpassword.InvalidFileFormatException Class Reference

caellion-python-commons

caellion.pycommons.stringutil.unixpassword.InvalidFileFormatException Class Reference

This exception is raised when encountering invalid or non-uniform line. More...

Inheritance diagram for caellion.pycommons.stringutil.unixpassword.InvalidFileFormatException:

## Detailed Description

This exception is raised when encountering invalid or non-uniform line.

Definition at line 38 of file unixpassword.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/stringutil/unixpassword.py